@@ -1,5 +1,5 @@
 package CPANPLUS::YACSmoke;
-$CPANPLUS::YACSmoke::VERSION = '1.04';
+$CPANPLUS::YACSmoke::VERSION = '1.06';
 # Dist::Zilla: +PodWeaver
 #ABSTRACT: Yet Another CPANPLUS Smoke Tester
 
@@ -163,6 +163,8 @@ sub test {
   if ( $self->{local_lib} ) {
      $self->_setup_local_lib();
      $self->{conf}->_perl5lib( $ENV{PERL5LIB} );
+     $self->{conf}->set_conf( makeflags  => '' );
+     $self->{conf}->set_conf( buildflags => '' );
      $target = 'install';
      msg("Setup local::lib environment in '$ENV{PERL_LOCAL_LIB_ROOT}'");
   }
@@ -482,7 +484,7 @@ CPANPLUS::YACSmoke - Yet Another CPANPLUS Smoke Tester
 
 =head1 VERSION
 
-version 1.04
+version 1.06
 
 =head1 SYNOPSIS
 
